@@ -1,4 +1,4 @@
-/* $Id: Base.h,v 1.12 1999/11/06 05:50:57 glgay Exp $ */
+/* $Id: Base.h,v 1.1.1.1 2001/04/09 13:31:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -25,8 +25,10 @@
 
 /* ======================================================================= */
 /* Include(s): */
-#include <Xarm/CObject.h>
+#include <Xm/Xm.h>
+#include <Xm/Protocols.h>
 #include <Xarm/XarmArg.h>
+#include <Xarm/CObject.h>
 
 #if !defined(DELETE_ON_CLOSE)
 /*
@@ -60,7 +62,7 @@ typedef WObjectClass *WObject;
 */
 WObject WidgetToWObject(Widget);
 
-class WObjectClass : public CObject {
+class WObjectClass {
  private:
    friend WObject WidgetToWObject(Widget w);
    Widget wid;
@@ -93,23 +95,23 @@ class WObjectClass : public CObject {
 
    virtual ~WObjectClass();
 
-   operator Widget() const ; // auto cast self to widget 
-   operator Display*() const ; // auto cast self to Display *
+   Display      *display()    const { return XtDisplay(widget()); }
+   Widget        widget()     const { return wid; }
+   Widget        parent()     const { return XtParent(widget()); }
+   XtAppContext  appContext() const { return XtWidgetToApplicationContext(widget()); }
+   Window        window()     const { return XtWindow(widget()); }
 
-   Display *display() const { return XtDisplay(widget()); }
-   Widget widget()    const { return wid; }
-   Widget parent()    const { return XtParent(widget()); }
-   XtAppContext appContext() const;
-   Window window() const { return XtWindow(widget()); }
+   operator Widget() const   { return widget(); }  // auto cast self to widget 
+   operator Display*() const { return display(); } // auto cast self to Display *
 
    void destroyCallback(XtCallbackProc funcp, XtPointer data = NULL);  
    void addDestructor();
    void removeDestructor();
 
-   void manage() { XtManageChild(*this); }
+   void manage()   { XtManageChild(*this); }
    void unmanage() { XtUnmanageChild(*this); }
 
-   bool managed() const { return XtIsManaged(*this); }
+   bool managed() const     { return XtIsManaged(*this); }
    void managed(bool state) { state ? manage() : unmanage(); }
 
    /* Mapping and unmapping functions */
@@ -144,34 +146,14 @@ class WObjectClass : public CObject {
    /* get pixmap from a data if possible or return XmUNSPECIFIED_PIXMAP */
    Pixmap getPixmapFromData(const char **pdata) const; 
    
-   /* the callback routines */
-   void addCallback(_XtString type, 
-                    XtCallbackProc fp, 
-                    XtPointer closure=NULL);
-   void removeCallback(_XtString type,
-                       XtCallbackProc fp,
-                       XtPointer closure=NULL);
-   void removeAllCallbacks(_XtString type);
-
-   /* Make member function callback routines from class CObject visible */
-   void addCallback(Widget w,
-                    _XtString type, 
-                    p_msg fp, 
-                    XtPointer closure=NULL);
-   void removeCallback(Widget w,
-                       _XtString type,
-                       p_msg fp,
-                       XtPointer closure=NULL);
-   void removeAllCallbacks(Widget w, _XtString type);
-
    /* protocol routines */
    Atom addWMProtocol(char *atom_name, Bool add_if_exists=False);
    void addProtocol(Atom property, Atom protocol_to_add);
-
    /* Convenience routines */
    Boolean processTraversal(XmTraversalDirection d = XmTRAVERSE_CURRENT)
        { return XmProcessTraversal(widget(), d); }
    Widget getFocusWidget() { return XmGetFocusWidget(widget()); }
+   void removeAllCallbacks(_XtString cb_type);
 
    /* ToolTip functions.  All are static except add and remove */
    /* ToolTip Enable/Disable, Timeout, and Margin effect all tooltips */
@@ -190,4 +172,6 @@ class WObjectClass : public CObject {
 
 };
 
+#include <Xarm/Callback.h>
+
 #endif
