@@ -1,4 +1,4 @@
-/* $Id: ToggleBG.h,v 1.5 1999/11/06 05:50:59 glgay Exp $ */
+/* $Id: ToggleBG.h,v 1.1.1.1 2001/04/09 13:33:34 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -26,6 +26,7 @@
 /* ======================================================================= */
 /* Include(s): */
 #include <Xarm/LabelG.h>
+#include <Xm/ToggleBG.h>
 
 class ToggleButtonGadgetClass : public LabelGadgetClass {
  protected:
@@ -39,8 +40,8 @@ class ToggleButtonGadgetClass : public LabelGadgetClass {
    void valueChangedCallback(XtCallbackProc fp, XtPointer data = NULL) { XARM_SET_CALLBACK(XmNvalueChangedCallback); }
 
    /* convenience functions */
-   Boolean getState() const                             { return XmToggleButtonGetState(widget()); }
-   void setState(Boolean state, Boolean notify = FALSE) { XmToggleButtonSetState(widget(), state, notify); }
+   Boolean getState() const                             { return XmToggleButtonGadgetGetState(widget()); }
+   void setState(Boolean state, Boolean notify = FALSE) { XmToggleButtonGadgetSetState(widget(), state, notify); }
 
    /* resources */
    void fillOnSelect(Boolean val)             { XARM_SET_VALUE(XmNfillOnSelect); }
