@@ -67,12 +67,15 @@ public:
 
     XarmArg &operator()(String, XtArgVal);
     XarmArg &operator()(String, String, XtPointer, unsigned int);
+    XarmArg &operator()(String name, String resType, const char *val, unsigned int val_size)
+                       { return operator()(name, resType, (XtPointer)val, val_size); }
     XarmArg &operator()(String name, XtPointer      value) { return operator()(name, (XtArgVal)value); }
     XarmArg &operator()(String name, signed   int   value) { return operator()(name, (XtArgVal)value); }
     XarmArg &operator()(String name, unsigned int   value) { return operator()(name, (XtArgVal)value); }
     XarmArg &operator()(String name, unsigned long  value) { return operator()(name, (XtArgVal)value); }
     XarmArg &operator()(String name, signed   char  value) { return operator()(name, (XtArgVal)value); }
     XarmArg &operator()(String name, unsigned char  value) { return operator()(name, (XtArgVal)value); }
+    XarmArg &operator()(String name, const char    *value) { return operator()(name, (XtArgVal)value); }
 
     // This one allows you to use Xarm object pointers as widgets when setting resources.
     //
