@@ -71,6 +71,10 @@ class MatrixClass : public ManagerClass {
           { XARM_SET_CALLBACK(XmNtraverseCellCallback); }
     void writeCellCallback(XtCallbackProc fp, XtPointer data = NULL)
           { XARM_SET_CALLBACK(XmNwriteCellCallback); }
+#ifdef XARM_XBAE_HAS_VCC
+    void valueChangedCallback(XtCallbackProc fp, XtPointer data = NULL)
+          { XARM_SET_CALLBACK(XmNvalueChangedCallback); }
+#endif
 
     /* Resources */
     void             allowColumnResize(Boolean val)         { XARM_SET_VALUE(XmNallowColumnResize); }
@@ -212,6 +216,16 @@ class MatrixClass : public ManagerClass {
     void             visibleRows(Dimension val)             { XARM_SET_VALUE(XmNvisibleRows); }
     Dimension        visibleRows() const                    { XARM_GET_VALUE(Dimension, XmNvisibleRows); }
 
+#ifdef XARM_XBAE_HAS_CC
+    void             calcCursorPosition(Boolean val)        { XARM_SET_VALUE(XmNcalcCursorPosition); }
+    Boolean          calcCursorPosition() const             { XARM_GET_VALUE(Boolean, XmNcalcCursorPosition); }
+#endif
+
+#ifdef XARM_XBAE_HAS_TAB
+    void             trailingAttachedBottom(Boolean val)    { XARM_SET_VALUE(XmNtrailingAttachedBottom); }
+    Boolean          trailingAttachedBottom() const         { XARM_GET_VALUE(Boolean, XmNtrailingAttachedBottom); }
+#endif
+
     /* Convenience functions */
     /* NOTE:  Some of the arguments have been re-arranged from the actual */
     /*        Xbae calls to allow for easy default values */
@@ -276,6 +290,10 @@ class MatrixClass : public ManagerClass {
         return XbaeMatrixGetCellUserData(widget(), row, column);
     }
 
+#ifdef XARM_XBAE_HAS_GCW
+    int getColumnWidth(int column) const { return XbaeMatrixGetColumnWidth(widget(), column); }
+#endif
+
     String getColumnLabel(int column) const { return XbaeMatrixGetColumnLabel(widget(), column); }
 
     XtPointer getColumnUserData(int column) const { return XbaeMatrixGetColumnUserData(widget(), column); }
@@ -288,6 +306,10 @@ class MatrixClass : public ManagerClass {
 
     int getNumSelected() const { return XbaeMatrixGetNumSelected(widget()); }
 
+#ifdef XARM_XBAE_HAS_GRH
+    int getRowHeight(int row) const { return XbaeMatrixGetRowHeight(widget(), row); }
+#endif
+
     String getRowLabel(int row) const { return XbaeMatrixGetRowLabel(widget(), row); }
 
     XtPointer getRowUserData(int row) const { return XbaeMatrixGetRowUserData(widget(), row); }
@@ -320,6 +342,14 @@ class MatrixClass : public ManagerClass {
 
     void refreshCell(int row, int column) { XbaeMatrixRefreshCell(widget(), row, column); }
 
+#ifdef XARM_XBAE_HAS_RFC
+    void refreshColumn(int column) const { XbaeMatrixRefreshColumn(widget(), column); }
+#endif
+
+#ifdef XARM_XBAE_HAS_RFR
+    void refreshRow(int row) const { XbaeMatrixRefreshRow(widget(), row); }
+#endif
+
     int rowColToXY(int row, int col, int *x, int *y) const { return XbaeMatrixRowColToXY(widget(), row, col, x, y); }
 
     void selectAll() { XbaeMatrixSelectAll(widget()); }
@@ -342,6 +372,11 @@ class MatrixClass : public ManagerClass {
         XbaeMatrixSetCellUserData(widget(), row, col, data);
     }
 
+#ifdef XARM_XBAE_HAS_SCW
+    void setCellWidget(int row, int column, Widget w) { XbaeMatrixSetCellWidget(widget(), row, column, w); }
+    void setCellWidget(int row, int column, WObjectClass *w) { XbaeMatrixSetCellWidget(widget(), row, column, w->widget()); }
+#endif
+
     void setColumnBackgrounds(int pos, Pixel *colors, int num_colors) {
         XbaeMatrixSetColumnBackgrounds(widget(), pos, colors, num_colors);
     }
@@ -354,6 +389,10 @@ class MatrixClass : public ManagerClass {
 
     void setColumnUserData(int col, XtPointer data) { XbaeMatrixSetColumnUserData(widget(), col, data); }
 
+#ifdef XARM_XBAE_HAS_SCOLW
+    void setColumnWidth(int column, int width) { XbaeMatrixSetColumnWidth(widget(), column, width); }
+#endif
+
     void setRowBackgrounds(int pos, Pixel *colors, int num_colors) {
         XbaeMatrixSetRowBackgrounds(widget(), pos, colors, num_colors);
     }
@@ -362,6 +401,10 @@ class MatrixClass : public ManagerClass {
         XbaeMatrixSetRowColors(widget(), pos, colors, num_colors);
     }
 
+#ifdef XARM_XBAE_HAS_SRH
+    void setRowHeight(int row, int height) { XbaeMatrixSetRowHeight(widget(), row, height); }
+#endif
+
     void setRowLabel(int row, String val) { XbaeMatrixSetRowLabel(widget(), row, val); }
 
     void setRowUserData(int row, XtPointer data) { XbaeMatrixSetRowUserData(widget(), row, data); }
@@ -384,6 +427,11 @@ class MatrixClass : public ManagerClass {
 
     int getVisibleRows() const { return XbaeMatrixVisibleRows(widget()); }
 
+#ifdef XARM_XBAE_HAS_VERSION
+    int getVersionNum() const { return XbaeGetVersionNum(); }
+    const char *getVersionText() const { return XbaeGetVersionTxt(); }
+#endif
+
     // Extra functionality
     bool sort(int column, int direction = 0);  // 0 = ascending, 1 = descending
 };
